norm.RUVs.RdNormalize the dataset using RUV using replicate samples, and return the normalized dataset with adjusting factor.
norm.RUVs(raw, groups)| raw | raw count data in the format of data frame or matrix, with columns for samples and rows for genes. |
|---|---|
| groups | vector of characters indicating the group for each sample. |
list, containing dat.normed (normalized dataset), and the adjust.factor (adjusting factors) for the design matrix. The normalized dataset could only used for exploration, and adjusting factors are recommended as a covariate in the downstream analysis.
test.RUVs <- norm.RUVs(data.test, data.group)